#pragma glslify: import('../common.glsl')

#define BASE_BARS 24.0
#define SCALE 1.7
#define COLOR_SCALE (1.8/3.0)
#define COLOR_OFFSET 0.3
#define BASE_SPACING 0.005
#define PEAK_HEIGHT 0.005

void main()
{
  // Adjust bars and spacing for resolution.
  float NUM_BARS = BASE_BARS;
  float SPACING = BASE_SPACING;

  // Adjust for landscape.
  NUM_BARS *= u_resolution.x / u_resolution.y;

  if (u_resolution.x / u_pixelRatio < 200.0) {
    SPACING = 0.01;
  }

  vec2 uv = gl_FragCoord.xy / u_resolution.xy;
  float bar = floor(uv.x * NUM_BARS);
  float offset = bar/NUM_BARS;
  float height = getFrequencyValue(offset, FREQ_AMPLITUDE) * SCALE;
  float peak = max(getFrequencyValue(offset, FREQ_PEAKS) * SCALE, height);

  // The background.
  gl_FragColor = vec4(0.);

  // Shade the peaks.
  if (peak > 0.01) {
    gl_FragColor = 0.5 * vec4(smoothstep(peak-PEAK_HEIGHT, peak, uv.y) - smoothstep(peak, peak+PEAK_HEIGHT, uv.y));
  }

  // The bar.
  if (uv.y < height) {
    gl_FragColor = vec4(getTweenedTexture(u_palette, uv.y * COLOR_SCALE + COLOR_OFFSET).rgb, 1);
  }

  // The lines between the bars.
  gl_FragColor *= smoothstep(0.0, 0.005, abs(uv.x - offset));// - smoothstep(0.05, 0.06, abs(uv.x - offset));
}
